==> stack_graphs_python_bindings-0.0.10.tar.gz: stack_graphs_python_bindings-0.0.10/tests/ts_ok_test.py <==
from helpers.virtual_files import string_to_virtual_files
from stack_graphs_python import Indexer, Querier, Language
import os

code1 = """
;---index.ts---
import { foo } from "./module";
         ^{ref1}
const baz: number = Number(foo);
                           ^{query}
console.log(baz);

;---module.ts---
export const foo: string = "42";
             ^{ref2}

"""

# Stack graphs will fail on this: TODO(@nohehf): Open issue
code2 = """
;---index.ts---
import { foo } from "./module.js";
         ^{ref1}
const baz: number = Number(foo);
                           ^{query}
console.log(baz);

;---module.ts---
export const foo: string = "42";
             ^{ref2}

"""

# Stack graphs will fail on this: TODO(@nohehf): Open issue
code3 = """
;---index.ts---
import { foo } from "./module.ts";
         ^{ref1}
const baz: number = Number(foo);
                           ^{query}
console.log(baz);

;---module.js---
export const foo: string = "42";
             ^{ref2}

"""


def test_ts_ok() -> None:
    with string_to_virtual_files(code1) as (dir, positions):
        db_path = os.path.join(dir, "db.sqlite")
        dir = os.path.abspath(dir)
        indexer = Indexer(db_path, [Language.TypeScript])
        indexer.index_all([dir])
        querier = Querier(db_path)
        source_reference = positions["query"]
        results = querier.definitions(source_reference)
        assert len(results) == 2
        expected = [positions["ref1"], positions["ref2"]]
        for i, result in enumerate(results):
            assert result == expected[i]


def test_ts_fails_should_be_ok() -> None:
    for code in [code2, code3]:
        with string_to_virtual_files(code) as (dir, positions):
            db_path = os.path.join(dir, "db.sqlite")
            dir = os.path.abspath(dir)
            indexer = Indexer(db_path, [Language.TypeScript])
            indexer.index_all([dir])
            querier = Querier(db_path)
            source_reference = positions["query"]
            results = querier.definitions(source_reference)
            assert (
                len(results) == 1
            )  # It should be 2, and find the ref2, but the module resolution doesn't work with file extensions
            assert results[0] == positions["ref1"]

==> stack_graphs_python_bindings-0.0.12.tar.gz: stack_graphs_python_bindings-0.0.12/tests/ts_ok_test.py <==
from helpers.virtual_files import string_to_virtual_files
from stack_graphs_python import Indexer, Querier, Language
import os

code1 = """
;---index.ts---
import { foo } from "./module";
         ^{ref1}
const baz: number = Number(foo);
                           ^{query}
console.log(baz);

;---module.ts---
export const foo: string = "42";
             ^{ref2}

"""

code2 = """
;---index.ts---
import { foo } from "./module.js";
         ^{ref1}
const baz: number = Number(foo);
                           ^{query}
console.log(baz);

;---module.ts---
export const foo: string = "42";
             ^{ref2}

"""

code3 = """
;---index.ts---
import { foo } from "./module.ts";
         ^{ref1}
const baz: number = Number(foo);
                           ^{query}
console.log(baz);

;---module.ts---
export const foo: string = "42";
             ^{ref2}

"""


def test_ts_ok() -> None:
    for code in [code1, code2, code3]:
        with string_to_virtual_files(code) as (dir, positions):
            db_path = os.path.join(dir, "db.sqlite")
            dir = os.path.abspath(dir)
            indexer = Indexer(db_path, [Language.TypeScript])
            indexer.index_all([dir])
            querier = Querier(db_path)
            source_reference = positions["query"]
            results = querier.definitions(source_reference)
            assert len(results) == 2
            expected = [positions["ref1"], positions["ref2"]]
            for i, result in enumerate(results):
                assert result == expected[i]
